<img width="500" height="500" alt="White Modern Technology Logo" src="https://github.com/user-attachments/assets/98834576-cdb7-4a99-91f4-8c224124f7c2" />

# Secapka
Secapka is a framework for APK analysis and automatic generation of mobile security reports.
